@@ -1,10 +1,7 @@
 package Net::Stripe::Simple;
-$Net::Stripe::Simple::VERSION = '0.002';
+$Net::Stripe::Simple::VERSION = '0.003';
 # ABSTRACT: simple, non-Moose interface to the Stripe API
 
-
-$Net::Stripe::Simple::VERSION //= '0.01';
-
 use v5.10;
 use strict;
 use warnings;
@@ -35,8 +32,11 @@ sub new {
     $class = ref($class) || $class;
     die 'API key required' unless $api;
     $version //= $STRIPE_VERSION;
+
+    my $pkg_version = $Net::Stripe::Simple::VERSION // '0.01';
+
     my $ua = LWP::UserAgent->new;
-    $ua->agent("$class/$Net::Stripe::Simple::VERSION");
+    $ua->agent("$class/$pkg_version");
     my $auth = 'Basic ' . encode_base64( $api . ':' );
     bless { ua => $ua, auth => $auth, version => $version }, $class;
 }
@@ -611,31 +611,29 @@ sub _encode_params {
             push @components, $ek . '=' . $value->{id};
             next;
         }
-        for ( reftype $value ) {
-            when ('HASH') {
-                for my $sk ( keys %$value ) {
-                    my $sv = $value->{$sk};
-                    next
-                      if ref $sv;  # don't think this PHP convention goes deeper
-                    push @components,
-                      $ek . '[' . uri_escape($sk) . ']=' . uri_escape($sv);
-                }
+
+        my $ref = ref($value);
+        if ($ref eq 'HASH') {
+            for my $sk ( keys %$value ) {
+                my $sv = $value->{$sk};
+                next
+                  if ref $sv;  # don't think this PHP convention goes deeper
+                push @components,
+                  $ek . '[' . uri_escape($sk) . ']=' . uri_escape($sv);
             }
-            when ('ARRAY') {
-                for my $sv (@$value) {
-                    next if ref $sv;    # again, I think we can't go deeper
-                    push @components, $ek . '[]=' . uri_escape($sv);
-                }
-            }
-            default {
-                $value =    # JSON boolean stringification magic has been erased
-                  ref $value eq 'JSON::PP::Boolean'
-                  ? $value
-                      ? 'true'
-                      : 'false'
-                  : uri_escape($value);
-                push @components, "$ek=$value"
+        } elsif ($ref eq 'ARRAY') {
+            for my $sv (@$value) {
+                next if ref $sv;    # again, I think we can't go deeper
+                push @components, $ek . '[]=' . uri_escape($sv);
             }
+        } else {
+            $value =    # JSON boolean stringification magic has been erased
+              ref $value eq 'JSON::PP::Boolean'
+              ? $value
+                  ? 'true'
+                  : 'false'
+              : uri_escape($value);
+            push @components, "$ek=$value"
         }
     }
     return join( '&', @components );
@@ -718,10 +716,13 @@ sub data_object {
     return unless $rr;
     die "forbidden class: $rr" if blessed($ref) and $rr !~ /^JSON::/;
     bless $ref, 'Net::Stripe::Simple::Data' if $rr eq 'HASH';
-    for ($rr) {
-        when ('HASH')  { data_object($_) for values %$ref }
-        when ('ARRAY') { data_object($_) for @$ref }
+
+    if ($rr eq 'HASH') {
+        data_object($_) for values %$ref
+    } elsif ($rr eq 'ARRAY') {
+        data_object($_) for @$ref
     }
+
     return $ref;
 }
 
@@ -752,7 +753,7 @@ Net::Stripe::Simple - simple, non-Moose interface to the Stripe API
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -837,6 +838,14 @@ The three constants plus C<data_object>.
 
 =back
 
+=head1 NAME
+
+Net::Stripe::Simple - simple, non-Moose interface to the Stripe API
+
+=head1 VERSION
+
+version 0.002
+
 =head1 METHODS
 
 =head2 new
@@ -874,7 +883,7 @@ B<Available Actions>
             customer => $customer,
             amount   => 100,
             currency => 'usd',
-            capture  => false,
+            capture  => 'false',
         }
     );
 
@@ -1583,4 +1592,25 @@ This software is copyright (c) 2014 by Grant Street Group.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Grant Street Group <developers@grantstreet.com>
+
+=item *
+
+David F. Houghton <dfhoughton@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Grant Street Group.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
