@@ -1,5 +1,5 @@
 package Net::Stripe::Simple::Data;
-$Net::Stripe::Simple::Data::VERSION = '0.002';
+$Net::Stripe::Simple::Data::VERSION = '0.003';
 # ABSTRACT: collection of methods to augment a JSON hash
 
 
@@ -40,17 +40,18 @@ sub unbless { _unbless(shift) }
 
 sub _unbless {
     my $v = shift;
-    for ( ref $v ) {
-        when ('ARRAY') {
-            return [ map { _unbless($_) } @$v ];
+    my $ref = ref($v);
+
+    if ($ref eq 'ARRAY') {
+        return [ map { _unbless($_) } @$v ];
+    } elsif ($ref eq 'Net::Stripe::Simple::Data') {
+        return {
+            map { $_ => _unbless( $v->{$_} ) } keys %$v
         }
-        when ('Net::Stripe::Simple::Data') {
-            return {
-                map { $_ => _unbless( $v->{$_} ) } keys %$v
-            }
-        }
-        when (/^JSON/) { return "$v" }
-        default        { return $v };
+    } elsif ($ref =~ /^JSON/) {
+        return "$v";
+    } else {
+        return $v;
     }
 }
 
@@ -68,7 +69,7 @@ Net::Stripe::Simple::Data - collection of methods to augment a JSON hash
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -148,6 +149,14 @@ is equivalent to
 
   $string eq $data;
 
+=head1 NAME
+
+Net::Stripe::Simple::Data - collection of methods to augment a JSON hash
+
+=head1 VERSION
+
+version 0.002
+
 =head1 METHODS
 
 =head2 $self->unbless
@@ -177,4 +186,25 @@ This software is copyright (c) 2014 by Grant Street Group.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Grant Street Group <developers@grantstreet.com>
+
+=item *
+
+David F. Houghton <dfhoughton@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Grant Street Group.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
